.. _recipe_asr.fere:

asr.fere
========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.fere`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.fere.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.fere

or as a python module

.. code-block:: console

   $ python -m asr.fere

Detailed description
--------------------
Fitted elemental reference energies.

Steps
-----


asr.fere
^^^^^^^^
.. autofunction:: asr.fere.main
   